Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(901)

Unified Diff: base/android/sys_utils_unittest.cc

Issue 258663002: Expose a low-end device mode override flags for non-android OSs as well (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: address review comments. Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « base/android/sys_utils.cc ('k') | base/base_switches.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/android/sys_utils_unittest.cc
diff --git a/base/android/sys_utils_unittest.cc b/base/android/sys_utils_unittest.cc
index 2a5a17d8532c363fa7fb1f61871d1133cabb3fd1..fc0282ad713c310fd273f322d3ebca9c754cf904 100644
--- a/base/android/sys_utils_unittest.cc
+++ b/base/android/sys_utils_unittest.cc
@@ -2,10 +2,9 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#include "base/android/sys_utils.h"
-
#include <unistd.h>
+#include "base/sys_info.h"
#include "testing/gtest/include/gtest/gtest.h"
namespace base {
@@ -13,10 +12,10 @@ namespace android {
TEST(SysUtils, AmountOfPhysicalMemory) {
// Check that the RAM size reported by sysconf() matches the one
// computed by base::android::SysUtils::AmountOfPhysicalMemory().
size_t sys_ram_size =
static_cast<size_t>(sysconf(_SC_PHYS_PAGES) * PAGE_SIZE);
- EXPECT_EQ(sys_ram_size, SysUtils::AmountOfPhysicalMemoryKB() * 1024UL);
+ EXPECT_EQ(sys_ram_size, SysInfo::AmountOfPhysicalMemory());
}
} // namespace android
« no previous file with comments | « base/android/sys_utils.cc ('k') | base/base_switches.h » ('j') | no next file with comments »
@@ -13,10 +12,10 @@ namespace android {
TEST(SysUtils, AmountOfPhysicalMemory) {
// Check that the RAM size reported by sysconf() matches the one
- // computed by base::android::SysUtils::AmountOfPhysicalMemory().
+ // computed by base::SysInfo::AmountOfPhysicalMemory().
size_t sys_ram_size =
static_cast<size_t>(sysconf(_SC_PHYS_PAGES) * PAGE_SIZE);

Powered by Google App Engine
This is Rietveld 408576698